//	Player.cpp - The player caterpillar.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "drawing/Drawer.h"
#include "ColourHelpers.h"
#include "Player.h"
#include "Random.h"

//------------------------------------------------------------------------------
Player::Player():
colour(1.0f)
{
	int i;
	TwoIntThing tempInts;
	ThreeFloats tempCol;

	for(i=13;i>5;--i)
	{
		tempInts.pos.x = i;
		tempInts.pos.y = 0;
		tempInts.size = 0.0f;
		tempCol.x = Random::getGlobal().getRandomFloat();
		tempCol.y = 0.75f;
		tempCol.z = 0.5f;
		tempInts.colour = ColourHelpers::hslToRgb(tempCol);
		//tempInts.colourTween = shared_ptr<STweener<ThreeFloats> >(new
		segments.push_back(tempInts);
	}
}

//------------------------------------------------------------------------------
Player::~Player()
{

}

//------------------------------------------------------------------------------
void Player::draw(shared_ptr<Drawer>& d)
{
	int i;

	for(i=1;i<(int)segments.size();++i)
	{
		if(segments[i].size > 0.0f)
			segments[i].size -= 0.05f;

		d->drawImage(L"Blob",
					 TwoFloats((segments[i].pos.x*64.0f)-(32.0f*segments[i].size),
							   (segments[i].pos.y*64.0f)-(32.0f*segments[i].size)),
					 1.0f+segments[i].size,
					 colour);
	}
	if(segments[0].size > 0.0f)
		segments[0].size -= 0.05f;

	d->drawImage(L"Head",
				 TwoFloats((segments[0].pos.x*64.0f)-(32.0f*segments[0].size),
						   (segments[0].pos.y*64.0f)-(32.0f*segments[0].size)),
				 1.0f+segments[0].size,
				 colour);
}

//------------------------------------------------------------------------------
void Player::move(int dir)
{
	int i;
	bool foundSegment = false;

	switch(dir)
	{
		case 1: //Left.
			if(segments.front().pos.x > 0)
			{
				for(i=0;i<(int)segments.size();++i)
				{
					if((segments[i].pos.x == (segments.front().pos.x-1)) &&
					   (segments[i].pos.y == segments.front().pos.y))
					{
						foundSegment = true;
						break;
					}
				}
				if(!foundSegment)
				{
					moveSegmentsOn();
					--(segments.front().pos.x);
				}
			}
			break;
		case 2: //Up.
			if(segments.front().pos.y > 0)
			{
				for(i=0;i<(int)segments.size();++i)
				{
					if((segments[i].pos.y == (segments.front().pos.y-1)) &&
					   (segments[i].pos.x == segments.front().pos.x))
					{
						foundSegment = true;
						break;
					}
				}
				if(!foundSegment)
				{
					moveSegmentsOn();
					--(segments.front().pos.y);
				}
			}
			break;
		case 3: //Right.
			if(segments.front().pos.x < 19)
			{
				for(i=0;i<(int)segments.size();++i)
				{
					if((segments[i].pos.x == (segments.front().pos.x+1)) &&
					   (segments[i].pos.y == segments.front().pos.y))
					{
						foundSegment = true;
						break;
					}
				}
				if(!foundSegment)
				{
					moveSegmentsOn();
					++(segments.front().pos.x);
				}
			}
			break;
		case 4: //Down.
			if(segments.front().pos.y < 10)
			{
				for(i=0;i<(int)segments.size();++i)
				{
					if((segments[i].pos.y == (segments.front().pos.y+1)) &&
					   (segments[i].pos.x == segments.front().pos.x))
					{
						foundSegment = true;
						break;
					}
				}
				if(!foundSegment)
				{
					moveSegmentsOn();
					++(segments.front().pos.y);
				}
			}
			break;
	}
}

//------------------------------------------------------------------------------
void Player::scaleSegment(int index)
{
	segments[index].size = 1.0f;
}

//------------------------------------------------------------------------------
void Player::setColour(const ThreeFloats& col)
{
	colour = col;
}

//------------------------------------------------------------------------------
void Player::moveSegmentsOn()
{
	int i;

	for(i=(segments.size()-1);i>0;--i)
	{
		segments[i].pos.x = segments[i-1].pos.x;
		segments[i].pos.y = segments[i-1].pos.y;
	}
}
