//	Player.h - The player caterpillar.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef PLAYER_H_
#define PLAYER_H_

#include "c0xHeaders.h"
#include "TwoFloats.h"
#include "TwoInts.h"
#include "Tweener.h"

#include <vector>

class Drawer;

///	The player caterpillar.
class Player
{
  public:
	///	Constructor.
	Player();
	///	Destructor.
	~Player();

	///	Draws the caterpillar.
	void draw(shared_ptr<Drawer>& d);

	///	Moves the caterpillar.
	/*!
		\param dir 1=left, 2=up, 3=right, 4=down
	 */
	void move(int dir);

	///	Simple struct representing the position of a segment.
	struct TwoIntThing
	{
		float size;
		TwoInts pos;
		ThreeFloats colour;
		//shared_ptr<STweener<ThreeFloats> > colourTween;
	};

	///	Scales up the indexed segment.
	void scaleSegment(int index);
	///	Sets the caterpillar's colour.
	void setColour(const ThreeFloats& col);

	///	Returns the number of caterpillar segments.
	int getNumSegments() const {return segments.size();};
	///	Returns the position of the first caterpillar segment.
	const TwoFloats getHeadPosition() const {return TwoFloats((segments[0].pos.x*64.0f)+32.0f, (segments[0].pos.y*64.0f)+32.0f);};
	///	Returns the caterpillar's segments.
	const std::vector<TwoIntThing>& getSegments() const {return segments;};
	///	Returns the TwoInts position of the indexed segment.
	const TwoInts& getSegmentPosition(int index) const {return segments[index].pos;};
	///	The colour of the caterpillar.
	const ThreeFloats& getColour() const {return colour;};
  private:
	///	Helper method. Moves all the segments along to the previous position of the next segment.
	void moveSegmentsOn();

	///	The caterpillar segments.
	std::vector<TwoIntThing> segments;
	///	The caterpillar's colour.
	ThreeFloats colour;
};

#endif
