//	PlayerGhost.cpp - The PlayerGhost caterpillar.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "drawing/Drawer.h"
#include "ColourHelpers.h"
#include "PlayerGhost.h"
#include "Random.h"

//------------------------------------------------------------------------------
PlayerGhost::PlayerGhost():
colour(1.0f),
storedIndex(0)
{
	int i;
	TwoIntThing tempInts;
	ThreeFloats tempCol;

	storedDir.x = 1;
	storedDir.y = 1;

	for(i=13;i>5;--i)
	{
		tempInts.pos.x = -1;
		tempInts.pos.y = -1;
		tempInts.size = 0.0f;
		tempCol.x = Random::getGlobal().getRandomFloat();
		tempCol.y = 0.75f;
		tempCol.z = 0.5f;
		tempInts.colour = ColourHelpers::hslToRgb(tempCol);
		segments.push_back(tempInts);
		storedSegments.push_back(tempInts);
	}
}

//------------------------------------------------------------------------------
PlayerGhost::~PlayerGhost()
{

}

//------------------------------------------------------------------------------
void PlayerGhost::draw(shared_ptr<Drawer>& d)
{
	int i;

	for(i=1;i<(int)segments.size();++i)
	{
		if(segments[i].size > 0.0f)
			segments[i].size -= 0.05f;

		d->drawImage(L"Blob",
					 TwoFloats((segments[i].pos.x*64.0f)-(32.0f*segments[i].size),
							   (segments[i].pos.y*64.0f)-(32.0f*segments[i].size)),
					 1.0f+segments[i].size,
					 colour,
					 0.5f);
	}
	if(segments[0].size > 0.0f)
		segments[0].size -= 0.05f;

	d->drawImage(L"Head",
				 TwoFloats((segments[0].pos.x*64.0f)-(32.0f*segments[0].size),
						   (segments[0].pos.y*64.0f)-(32.0f*segments[0].size)),
				 1.0f+segments[0].size,
				 colour,
				 0.5f);
}

//------------------------------------------------------------------------------
void PlayerGhost::setColour(const ThreeFloats& col)
{
	colour = col;
}

//------------------------------------------------------------------------------
void PlayerGhost::resetSegments()
{
	int i;

	for(i=0;i<segments.size();++i)
	{
		segments[i].pos = -1;
		storedSegments[i].pos = -1;
	}
}

//------------------------------------------------------------------------------
void PlayerGhost::setSegment(int index, int x, int y)
{
	segments[index].pos.x = x;
	segments[index].pos.y = y;
	storedSegments[index].pos.x = x;
	storedSegments[index].pos.y = y;
}

//------------------------------------------------------------------------------
void PlayerGhost::scaleSegment(int index)
{
	segments[index].size = 1.0f;
}

//------------------------------------------------------------------------------
void PlayerGhost::loopOneSegment()
{
	int i;
	int tempint;
	TwoInts dir;
	int index2 = (storedIndex+1)%8;

	for(i=(segments.size()-1);i>0;--i)
	{
		segments[i].pos.x = segments[i-1].pos.x;
		segments[i].pos.y = segments[i-1].pos.y;
		segments[i].colour = segments[i-1].colour;
		segments[i].size = segments[i-1].size;
	}

	if(storedSegments[storedIndex].pos.x == storedSegments[index2].pos.x)
		dir.x = 0;
	else if(storedSegments[storedIndex].pos.x > storedSegments[index2].pos.x)
		dir.x = 1;
	else
		dir.x = -1;
	if(storedSegments[storedIndex].pos.y == storedSegments[index2].pos.y)
		dir.y = 0;
	else if(storedSegments[storedIndex].pos.y > storedSegments[index2].pos.y)
		dir.y = 1;
	else
		dir.y = -1;

	tempint = segments[0].pos.x + (dir.x * storedDir.x);
	if((tempint > 19) || (tempint < 0))
	{
		storedDir.x = -storedDir.x;
		segments[0].pos.x += dir.x * storedDir.x;
	}
	else
		segments[0].pos.x = tempint;

	tempint = segments[0].pos.y + (dir.y * storedDir.y);
	if((tempint > 10) || (tempint < 0))
	{
		storedDir.y = -storedDir.y;
		segments[0].pos.y += dir.y * storedDir.y;
	}
	else
		segments[0].pos.y = tempint;

	++storedIndex;
	storedIndex %= storedSegments.size();
} 
