//	PlayerGhost.h - The PlayerGhost caterpillar.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef PLAYERGHOST_H_
#define PLAYERGHOST_H_

#include "ThreeFloats.h"
#include "c0xHeaders.h"
#include "TwoFloats.h"
#include "Tweener.h"
#include "TwoInts.h"

#include <vector>

class Drawer;

///	The PlayerGhost caterpillar.
class PlayerGhost
{
  public:
	///	Constructor.
	PlayerGhost();
	///	Destructor.
	~PlayerGhost();

	///	Draws the caterpillar.
	void draw(shared_ptr<Drawer>& d);

	///	Sets the ghost's colour.
	void setColour(const ThreeFloats& col);
	///	Returns the ghost's colour.
	const ThreeFloats& getColour() const {return colour;};

	///	Simple struct representing the position of a segment.
	struct TwoIntThing
	{
		float size;
		TwoInts pos;
		ThreeFloats colour;
		//shared_ptr<STweener<ThreeFloats> > colourTween;
	};

	///	Resets the caterpillar's segments.
	void resetSegments();
	///	Sets the caterpillar's segments.
	void setSegment(int index, int x, int y);

	///	Scales up the indexed segment.
	void scaleSegment(int index);

	///	Tells the ghost to loop yellowtail-style.
	void loopOneSegment();

	///	Returns the number of caterpillar segments.
	int getNumSegments() const {return segments.size();};
	///	Returns the position of the first caterpillar segment.
	const TwoFloats getHeadPosition() const {return TwoFloats((segments[0].pos.x*64.0f)+32.0f, (segments[0].pos.y*64.0f)+32.0f);};
	///	Returns the TwoInts position of the indexed segment.
	const TwoInts& getSegmentPosition(int index) const {return segments[index].pos;};
	///	Returns the caterpillar's segments.
	const std::vector<TwoIntThing>& getSegments() const {return segments;};
  private:
	///	The caterpillar segments.
	std::vector<TwoIntThing> segments;
	///	The caterpillar's colour.
	ThreeFloats colour;

	///	The stored segments, in their original order.
	std::vector<TwoIntThing> storedSegments;
	///	The loop position within storedSegments.
	int storedIndex;
	///	The loop direction within storedSegments.
	TwoInts storedDir;
};

#endif
