//	TwoInts.h - Simple TwoInts class
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef TWOINTS_H_
#define TWOINTS_H_

///	Simple TwoInts class
struct TwoInts
{
	///	Constructor.
	TwoInts(int valX, int valY):
	x(valX),
	y(valY)
	{

	};
	///	Default constructor.
	TwoInts():
	x(0),
	y(0)
	{

	};

	///	Addition operator.
	const TwoInts operator+(const TwoInts& val) const
	{
		TwoInts retval;

		retval.x = x + val.x;
		retval.y = y + val.y;

		return retval;
	};
	///	Subtraction operator.
	const TwoInts operator-(const TwoInts& val) const
	{
		TwoInts retval;

		retval.x = x - val.x;
		retval.y = y - val.y;

		return retval;
	};
	///	Multiplication operator.
	const TwoInts operator*(const TwoInts& val) const
	{
		TwoInts retval;

		retval.x = x * val.x;
		retval.y = y * val.y;

		return retval;
	};
	///	Division operator.
	const TwoInts operator/(const TwoInts& val) const
	{
		TwoInts retval;

		retval.x = x / val.x;
		retval.y = y / val.y;

		return retval;
	};
	///	Assignment operator.
	const TwoInts& operator=(const TwoInts& val)
	{
		x = val.x;
		y = val.y;

		return *this;
	}
	///	Assignment operator.
	const TwoInts& operator=(float val)
	{
		x = val;
		y = val;

		return *this;
	}

	///	Equality test.
	bool operator==(const TwoInts& val) const
	{
		return ((x == val.x) && (y == val.y));
	};
	///	Inequality test.
	bool operator!=(const TwoInts& val) const
	{
		return ((x != val.x) || (y != val.y));
	};
	///	Less-than test.
	bool operator<(const TwoInts& val) const
	{
		return ((x < val.x) || (y < val.y));
	};

	///	The x value.
	int x;
	///	The y value.
	int y;
};

#endif
