//	KickSynth2.h - A kick synth based on MonophonicSynth.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef KICKSYNTH2_H_
#define KICKSYNTH2_H_

#include "MonophonicSynth.h"

///	A kick synth based on MonophonicSynth.
class KickSynth2 : public MonophonicSynth
{
  public:
	///	Constructor.
	KickSynth2();
	///	Destructor.
	~KickSynth2();

	///	Returns the audio for this synth.
	void getAudio(float *buffer, int numSamples);

	///	Triggers a note at the specified frequency.
	void triggerNote(float freq, int sample, float amp);
	///	Sets the named parameter.
	void setParameter(const std::string& name, float value, bool direct = false);
	///	Returns the number of parameters this synth has.
	int getNumParameters() const {return 1;};
	///	Returns the value of the indexed parameter.
	float getParameter(int i) const {return amplitude;};
	///	Returns the name of the indexed parameter.
	std::string getParameterName(int i) const {return "Amplitude";};
  private:
	///	Which sample to start on in the next audio block.
	int start;

	///	The length of the kick sound (counts down).
	float length;
	///	The value used to count down length.
	float increment;

	///	For the sine generation.
	float x0;
	///	For the sine generation.
	float x1;
	///	For the sine generation.
	float coeff;

	///	We interpolate between coefficients to save on the sin() calls.
	float hiCoeff[2];
	///	Which hiCoeff we're using.
	int hiIndex;
	///	We interpolate between coefficients to save on the sin() calls.
	float loCoeff;

	///	The synth's amplitude parameter.
	float amplitude;
};

#endif
